API reference
=============

Type aliases
------------

* ``Sample = Mapping[FieldName, FieldValue]``
* ``FieldName = str``
* ``FieldValue = Union[float, int, str, Sequence[FieldValue]``

Classes
-------

.. currentmodule:: text2array

Vocab
^^^^^

.. autoclass:: Vocab
   :members:
   :show-inheritance:

ShuffleIterator
^^^^^^^^^^^^^^^

.. autoclass:: ShuffleIterator
   :members:
   :show-inheritance:

BatchIterator
^^^^^^^^^^^^^

.. autoclass:: BatchIterator
   :members:
   :show-inheritance:

Batch
^^^^^

.. autoclass:: Batch
   :members:
   :show-inheritance:

StringStore
^^^^^^^^^^^

.. autoclass:: StringStore
